@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -62,9 +62,13 @@ class CControllerMediatypeDisable extends CController {
 
 		$updated = count($mediatypes);
 
-		$response = new CControllerResponseRedirect('zabbix.php?action=mediatype.list&uncheck=1');
+		$response = new CControllerResponseRedirect((new CUrl('zabbix.php'))
+			->setArgument('action', 'mediatype.list')
+			->setArgument('page', CPagerHelper::loadPage('mediatype.list', null))
+		);
 
 		if ($result) {
+			$response->setFormData(['uncheck' => '1']);
 			$response->setMessageOk(_n('Media type disabled', 'Media types disabled', $updated));
 		}
 		else {
