@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -61,13 +61,13 @@ $fields = [
 									],
 	'delay_flex' =>					[T_ZBX_STR, O_OPT, null,	null,			null],
 	'status' =>						[T_ZBX_INT, O_OPT, null,	IN([ITEM_STATUS_ACTIVE, ITEM_STATUS_DISABLED]), null],
+	'discover' =>					[T_ZBX_INT, O_OPT, null,	IN([ZBX_PROTOTYPE_DISCOVER, ZBX_PROTOTYPE_NO_DISCOVER]), null],
 	'type' =>						[T_ZBX_INT, O_OPT, null,
-										IN([-1, ITEM_TYPE_ZABBIX, ITEM_TYPE_SNMPV1, ITEM_TYPE_TRAPPER, ITEM_TYPE_SIMPLE,
-											ITEM_TYPE_SNMPV2C, ITEM_TYPE_INTERNAL, ITEM_TYPE_SNMPV3,
-											ITEM_TYPE_ZABBIX_ACTIVE, ITEM_TYPE_AGGREGATE, ITEM_TYPE_EXTERNAL,
-											ITEM_TYPE_DB_MONITOR, ITEM_TYPE_IPMI, ITEM_TYPE_SSH, ITEM_TYPE_TELNET,
-											ITEM_TYPE_JMX, ITEM_TYPE_CALCULATED, ITEM_TYPE_SNMPTRAP,
-											ITEM_TYPE_DEPENDENT, ITEM_TYPE_HTTPAGENT
+										IN([-1, ITEM_TYPE_ZABBIX, ITEM_TYPE_TRAPPER, ITEM_TYPE_SIMPLE,
+											ITEM_TYPE_INTERNAL, ITEM_TYPE_ZABBIX_ACTIVE, ITEM_TYPE_AGGREGATE,
+											ITEM_TYPE_EXTERNAL, ITEM_TYPE_DB_MONITOR, ITEM_TYPE_IPMI, ITEM_TYPE_SSH,
+											ITEM_TYPE_TELNET, ITEM_TYPE_JMX, ITEM_TYPE_CALCULATED, ITEM_TYPE_SNMPTRAP,
+											ITEM_TYPE_DEPENDENT, ITEM_TYPE_HTTPAGENT, ITEM_TYPE_SNMP
 										]),
 										'isset({add}) || isset({update})'
 									],
@@ -103,62 +103,12 @@ $fields = [
 											),
 										getParamFieldLabelByType(getRequest('type', 0))
 									],
-	'snmp_community' =>				[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,
-										'(isset({add}) || isset({update})) && isset({type})'.
-											' && '.IN(ITEM_TYPE_SNMPV1.','.ITEM_TYPE_SNMPV2C, 'type'),
-										_('SNMP community')
-									],
 	'snmp_oid' =>					[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,
 										'(isset({add}) || isset({update})) && isset({type})'.
-											' && '.IN(ITEM_TYPE_SNMPV1.','.ITEM_TYPE_SNMPV2C.','.ITEM_TYPE_SNMPV3,
-												'type'
-											),
+											' && {type} == '.ITEM_TYPE_SNMP,
 										_('SNMP OID')
 									],
-	'port' =>						[T_ZBX_STR, O_OPT, null,	BETWEEN(0, 65535),
-										'(isset({add}) || isset({update})) && isset({type})'.
-											' && '.IN(ITEM_TYPE_SNMPV1.','.ITEM_TYPE_SNMPV2C.','.ITEM_TYPE_SNMPV3,
-												'type'
-											),
-										_('Port')
-									],
-	'snmpv3_securitylevel' =>		[T_ZBX_INT, O_OPT, null,	IN('0,1,2'),
-										'(isset({add}) || isset({update})) && isset({type})'.
-											' && {type} == '.ITEM_TYPE_SNMPV3
-									],
-	'snmpv3_contextname' =>			[T_ZBX_STR, O_OPT, null,	null,
-										'(isset({add}) || isset({update})) && isset({type})'.
-											' && {type} == '.ITEM_TYPE_SNMPV3
-									],
-	'snmpv3_securityname' =>		[T_ZBX_STR, O_OPT, null,	null,
-										'(isset({add}) || isset({update})) && isset({type})'.
-											' && {type} == '.ITEM_TYPE_SNMPV3
-									],
-	'snmpv3_authprotocol' =>		[T_ZBX_INT, O_OPT, null,	IN(ITEM_AUTHPROTOCOL_MD5.','.ITEM_AUTHPROTOCOL_SHA),
-										'(isset({add}) || isset({update})) && isset({type})'.
-											' && {type} == '.ITEM_TYPE_SNMPV3.
-											' && ({snmpv3_securitylevel} == '.ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV.
-												' || {snmpv3_securitylevel} == '.ITEM_SNMPV3_SECURITYLEVEL_AUTHNOPRIV.
-										')'
-									],
-	'snmpv3_authpassphrase' =>		[T_ZBX_STR, O_OPT, null,	null,
-										'(isset({add}) || isset({update})) && isset({type})'.
-											' && {type} == '.ITEM_TYPE_SNMPV3.
-											' && ({snmpv3_securitylevel} == '.ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV.
-												' || {snmpv3_securitylevel} == '.ITEM_SNMPV3_SECURITYLEVEL_AUTHNOPRIV.
-										')'
-									],
-	'snmpv3_privprotocol' =>		[T_ZBX_INT, O_OPT, null,	IN(ITEM_PRIVPROTOCOL_DES.','.ITEM_PRIVPROTOCOL_AES),
-										'(isset({add}) || isset({update})) && isset({type})'.
-											' && {type} == '.ITEM_TYPE_SNMPV3.
-											' && {snmpv3_securitylevel} == '.ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV
-									],
-	'snmpv3_privpassphrase' =>		[T_ZBX_STR, O_OPT, null,	null,
-										'(isset({add}) || isset({update})) && isset({type})'.
-											' && {type} == '.ITEM_TYPE_SNMPV3.
-											' && {snmpv3_securitylevel} == '.ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV
-									],
-	'ipmi_sensor' =>				[T_ZBX_STR, O_OPT, P_NO_TRIM,	NOT_EMPTY,
+	'ipmi_sensor' =>				[T_ZBX_STR, O_OPT, P_NO_TRIM, null,
 										'(isset({add}) || isset({update})) && isset({type})'.
 											' && {type} == '.ITEM_TYPE_IPMI,
 										_('IPMI sensor')
@@ -297,7 +247,7 @@ $fields = [
 	'filter_set' =>					[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
 	// sort and sortorder
 	'sort' =>						[T_ZBX_STR, O_OPT, P_SYS,
-										IN('"delay","history","key_","name","status","trends","type"'), null
+										IN('"delay","history","key_","name","status","trends","type","discover"'), null
 									],
 	'sortorder' =>					[T_ZBX_STR, O_OPT, P_SYS, IN('"'.ZBX_SORT_DOWN.'","'.ZBX_SORT_UP.'"'),	null]
 ];
@@ -499,6 +449,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 
 				case ZBX_PREPROC_REGSUB:
 				case ZBX_PREPROC_ERROR_FIELD_REGEX:
+				case ZBX_PREPROC_STR_REPLACE:
 					$step['params'] = implode("\n", $step['params']);
 					break;
 
@@ -529,23 +480,15 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			'interfaceid'	=> getRequest('interfaceid'),
 			'delay'			=> $delay,
 			'status'		=> getRequest('status', ITEM_STATUS_DISABLED),
+			'discover'		=> getRequest('discover', ZBX_PROTOTYPE_DISCOVER),
 			'type'			=> getRequest('type'),
-			'snmp_community' => getRequest('snmp_community'),
 			'snmp_oid'		=> getRequest('snmp_oid'),
 			'value_type'	=> getRequest('value_type'),
 			'trapper_hosts'	=> getRequest('trapper_hosts'),
-			'port'			=> getRequest('port'),
 			'history'		=> (getRequest('history_mode', ITEM_STORAGE_CUSTOM) == ITEM_STORAGE_OFF)
 				? ITEM_NO_STORAGE_VALUE
 				: getRequest('history'),
 			'units'			=> getRequest('units'),
-			'snmpv3_contextname' => getRequest('snmpv3_contextname'),
-			'snmpv3_securityname' => getRequest('snmpv3_securityname'),
-			'snmpv3_securitylevel' => getRequest('snmpv3_securitylevel'),
-			'snmpv3_authprotocol' => getRequest('snmpv3_authprotocol'),
-			'snmpv3_authpassphrase' => getRequest('snmpv3_authpassphrase'),
-			'snmpv3_privprotocol' => getRequest('snmpv3_privprotocol'),
-			'snmpv3_privpassphrase' => getRequest('snmpv3_privpassphrase'),
 			'logtimefmt'	=> getRequest('logtimefmt'),
 			'valuemapid'	=> getRequest('valuemapid'),
 			'authtype'		=> getRequest('authtype'),
@@ -576,15 +519,14 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			$itemId = getRequest('itemid');
 
 			$db_item = API::ItemPrototype()->get([
-				'output' => ['type', 'snmp_community', 'snmp_oid', 'hostid', 'name', 'key_', 'delay', 'history',
-					'trends', 'status', 'value_type', 'trapper_hosts', 'units', 'snmpv3_securityname',
-					'snmpv3_securitylevel', 'snmpv3_authpassphrase', 'snmpv3_privpassphrase', 'logtimefmt',
-					'templateid', 'valuemapid', 'params', 'ipmi_sensor', 'authtype', 'username', 'password',
-					'publickey', 'privatekey', 'interfaceid', 'port', 'description', 'snmpv3_authprotocol',
-					'snmpv3_privprotocol', 'snmpv3_contextname', 'jmx_endpoint', 'master_itemid', 'timeout', 'url',
-					'query_fields', 'posts', 'status_codes', 'follow_redirects', 'post_type', 'http_proxy', 'headers',
-					'retrieve_mode', 'request_method', 'output_format', 'ssl_cert_file', 'ssl_key_file',
-					'ssl_key_password', 'verify_peer', 'verify_host', 'allow_traps'
+				'output' => ['type', 'snmp_oid', 'hostid', 'name', 'key_', 'delay', 'history',
+					'trends', 'status', 'value_type', 'trapper_hosts', 'units',
+					'logtimefmt', 'templateid', 'valuemapid', 'params', 'ipmi_sensor', 'authtype', 'username',
+					'password', 'publickey', 'privatekey', 'interfaceid', 'description', 'jmx_endpoint',
+					'master_itemid', 'timeout', 'url', 'query_fields', 'posts', 'status_codes', 'follow_redirects',
+					'post_type', 'http_proxy', 'headers', 'retrieve_mode', 'request_method', 'output_format',
+					'ssl_cert_file', 'ssl_key_file', 'ssl_key_password', 'verify_peer', 'verify_host', 'allow_traps',
+					'discover'
 				],
 				'selectApplications' => ['applicationid'],
 				'selectApplicationPrototypes' => ['name'],
@@ -592,15 +534,6 @@ elseif (hasRequest('add') || hasRequest('update')) {
 				'itemids' => [$itemId]
 			]);
 
-			// unset snmpv3 fields
-			if ($item['snmpv3_securitylevel'] == ITEM_SNMPV3_SECURITYLEVEL_NOAUTHNOPRIV) {
-				$item['snmpv3_authprotocol'] = ITEM_AUTHPROTOCOL_MD5;
-				$item['snmpv3_privprotocol'] = ITEM_PRIVPROTOCOL_DES;
-			}
-			elseif ($item['snmpv3_securitylevel'] == ITEM_SNMPV3_SECURITYLEVEL_AUTHNOPRIV) {
-				$item['snmpv3_privprotocol'] = ITEM_PRIVPROTOCOL_DES;
-			}
-
 			$db_item = $db_item[0];
 
 			if ($item['type'] == ITEM_TYPE_HTTPAGENT) {
@@ -894,19 +827,10 @@ elseif ($valid_input && hasRequest('massupdate') && hasRequest('group_itemid'))
 						? ITEM_NO_STORAGE_VALUE
 						: getRequest('history'),
 					'type' => getRequest('type'),
-					'snmp_community' => getRequest('snmp_community'),
 					'snmp_oid' => getRequest('snmp_oid'),
 					'value_type' => getRequest('value_type'),
 					'trapper_hosts' => getRequest('trapper_hosts'),
-					'port' => getRequest('port'),
 					'units' => getRequest('units'),
-					'snmpv3_contextname' => getRequest('snmpv3_contextname'),
-					'snmpv3_securityname' => getRequest('snmpv3_securityname'),
-					'snmpv3_securitylevel' => getRequest('snmpv3_securitylevel'),
-					'snmpv3_authprotocol' => getRequest('snmpv3_authprotocol'),
-					'snmpv3_authpassphrase' => getRequest('snmpv3_authpassphrase'),
-					'snmpv3_privprotocol' => getRequest('snmpv3_privprotocol'),
-					'snmpv3_privpassphrase' => getRequest('snmpv3_privpassphrase'),
 					'trends' => (getRequest('trends_mode', ITEM_STORAGE_CUSTOM) == ITEM_STORAGE_OFF)
 						? ITEM_NO_STORAGE_VALUE
 						: getRequest('trends'),
@@ -921,6 +845,7 @@ elseif ($valid_input && hasRequest('massupdate') && hasRequest('group_itemid'))
 					'applications' => [],
 					'applicationPrototypes' => [],
 					'status' => getRequest('status'),
+					'discover' => getRequest('discover'),
 					'master_itemid' => getRequest('master_itemid'),
 					'url' =>  getRequest('url'),
 					'post_type' => getRequest('post_type'),
@@ -983,6 +908,7 @@ elseif ($valid_input && hasRequest('massupdate') && hasRequest('group_itemid'))
 
 							case ZBX_PREPROC_REGSUB:
 							case ZBX_PREPROC_ERROR_FIELD_REGEX:
+							case ZBX_PREPROC_STR_REPLACE:
 								$step['params'] = implode("\n", $step['params']);
 								break;
 
@@ -1038,7 +964,7 @@ elseif ($valid_input && hasRequest('massupdate') && hasRequest('group_itemid'))
 									}
 
 									/*
-									 * $upd_applicationids now contains new and existing application IDs depeding on
+									 * $upd_applicationids now contains new and existing application IDs depending on
 									 * operation we want to perform.
 									 */
 									$item_prototype['applications'] = array_keys(array_flip($upd_applicationids));
@@ -1210,15 +1136,13 @@ if (isset($_REQUEST['form'])) {
 		$itemPrototype = API::ItemPrototype()->get([
 			'itemids' => getRequest('itemid'),
 			'output' => [
-				'itemid', 'type', 'snmp_community', 'snmp_oid', 'hostid', 'name', 'key_', 'delay', 'history',
-				'trends', 'status', 'value_type', 'trapper_hosts', 'units', 'snmpv3_securityname',
-				'snmpv3_securitylevel', 'snmpv3_authpassphrase', 'snmpv3_privpassphrase', 'logtimefmt', 'templateid',
+				'itemid', 'type', 'snmp_oid', 'hostid', 'name', 'key_', 'delay', 'history',
+				'trends', 'status', 'value_type', 'trapper_hosts', 'units', 'logtimefmt', 'templateid',
 				'valuemapid', 'params', 'ipmi_sensor', 'authtype', 'username', 'password', 'publickey', 'privatekey',
-				'interfaceid', 'port', 'description', 'snmpv3_authprotocol', 'snmpv3_privprotocol',
-				'snmpv3_contextname', 'jmx_endpoint', 'master_itemid', 'timeout', 'url', 'query_fields', 'posts',
-				'status_codes', 'follow_redirects', 'post_type', 'http_proxy', 'headers', 'retrieve_mode',
+				'interfaceid', 'description', 'jmx_endpoint', 'master_itemid', 'timeout', 'url', 'query_fields',
+				'posts', 'status_codes', 'follow_redirects', 'post_type', 'http_proxy', 'headers', 'retrieve_mode',
 				'request_method', 'output_format', 'ssl_cert_file', 'ssl_key_file', 'ssl_key_password',
-				'verify_peer', 'verify_host', 'allow_traps'
+				'verify_peer', 'verify_host', 'allow_traps', 'discover'
 			],
 			'selectPreprocessing' => ['type', 'params', 'error_handler', 'error_handler_params']
 		]);
@@ -1277,7 +1201,7 @@ if (isset($_REQUEST['form'])) {
 
 	$data = getItemFormData($itemPrototype);
 	$data['config'] = select_config();
-	$data['preprocessing_test_type'] = CControllerPopupPreprocTestEdit::ZBX_TEST_TYPE_ITEM_PROTOTYPE;
+	$data['preprocessing_test_type'] = CControllerPopupItemTestEdit::ZBX_TEST_TYPE_ITEM_PROTOTYPE;
 	$data['preprocessing_types'] = CItemPrototype::$supported_preprocessing_types;
 	$data['trends_default'] = DB::getDefault('items', 'trends');
 
@@ -1306,9 +1230,7 @@ if (isset($_REQUEST['form'])) {
 
 	// render view
 	if (!$has_errors) {
-		$itemView = new CView('configuration.item.prototype.edit', $data);
-		$itemView->render();
-		$itemView->show();
+		echo (new CView('configuration.item.prototype.edit', $data))->getOutput();
 	}
 }
 elseif (((hasRequest('action') && getRequest('action') === 'itemprototype.massupdateform') || hasRequest('massupdate'))
@@ -1324,10 +1246,9 @@ elseif (((hasRequest('action') && getRequest('action') === 'itemprototype.massup
 		'delay_flex' => getRequest('delay_flex', []),
 		'history' => getRequest('history', DB::getDefault('items', 'history')),
 		'status' => getRequest('status', 0),
+		'discover' => getRequest('discover', DB::getDefault('items', 'discover')),
 		'type' => getRequest('type', 0),
 		'interfaceid' => getRequest('interfaceid', 0),
-		'snmp_community' => getRequest('snmp_community', 'public'),
-		'port' => getRequest('port', ''),
 		'value_type' => getRequest('value_type', ITEM_VALUE_TYPE_UINT64),
 		'trapper_hosts' => getRequest('trapper_hosts', ''),
 		'units' => getRequest('units', ''),
@@ -1341,13 +1262,6 @@ elseif (((hasRequest('action') && getRequest('action') === 'itemprototype.massup
 		'trends' => getRequest('trends', DB::getDefault('items', 'trends')),
 		'applications' => [],
 		'application_prototypes' => [],
-		'snmpv3_contextname' => getRequest('snmpv3_contextname', ''),
-		'snmpv3_securityname' => getRequest('snmpv3_securityname', ''),
-		'snmpv3_securitylevel' => getRequest('snmpv3_securitylevel', 0),
-		'snmpv3_authprotocol' => getRequest('snmpv3_authprotocol', ITEM_AUTHPROTOCOL_MD5),
-		'snmpv3_authpassphrase' => getRequest('snmpv3_authpassphrase', ''),
-		'snmpv3_privprotocol' => getRequest('snmpv3_privprotocol', ITEM_PRIVPROTOCOL_DES),
-		'snmpv3_privpassphrase' => getRequest('snmpv3_privpassphrase', ''),
 		'logtimefmt' => getRequest('logtimefmt', ''),
 		'preprocessing' => getRequest('preprocessing', []),
 		'initial_item_type' => null,
@@ -1361,7 +1275,7 @@ elseif (((hasRequest('action') && getRequest('action') === 'itemprototype.massup
 		'allow_traps' => getRequest('allow_traps', HTTPCHECK_ALLOW_TRAPS_OFF),
 		'massupdate_app_action' => getRequest('massupdate_app_action', ZBX_ACTION_ADD),
 		'massupdate_app_prot_action' => getRequest('massupdate_app_prot_action', ZBX_ACTION_ADD),
-		'preprocessing_test_type' => CControllerPopupPreprocTestEdit::ZBX_TEST_TYPE_ITEM_PROTOTYPE,
+		'preprocessing_test_type' => CControllerPopupItemTestEdit::ZBX_TEST_TYPE_ITEM_PROTOTYPE,
 		'preprocessing_types' => CItemPrototype::$supported_preprocessing_types,
 		'preprocessing_script_maxlength' => DB::getFieldLength('item_preproc', 'params')
 	];
@@ -1553,9 +1467,7 @@ elseif (((hasRequest('action') && getRequest('action') === 'itemprototype.massup
 		$data['trends_mode'] = getRequest('trends_mode', ITEM_STORAGE_CUSTOM);
 	}
 
-	$view = (new CView('configuration.item.prototype.massupdate', $data))
-		->render()
-		->show();
+	echo (new CView('configuration.item.prototype.massupdate', $data))->getOutput();
 }
 else {
 	$sortField = getRequest('sort', CProfile::get('web.'.$page['file'].'.sort', 'name'));
@@ -1602,16 +1514,27 @@ else {
 			order_result($data['items'], $sortField, $sortOrder);
 	}
 
-	$url = (new CUrl('disc_prototypes.php'))
-		->setArgument('parent_discoveryid', $data['parent_discoveryid']);
+	// pager
+	if (hasRequest('page')) {
+		$page_num = getRequest('page');
+	}
+	elseif (isRequestMethod('get') && !hasRequest('cancel')) {
+		$page_num = 1;
+	}
+	else {
+		$page_num = CPagerHelper::loadPage($page['file']);
+	}
+
+	CPagerHelper::savePage($page['file'], $page_num);
+
+	$data['paging'] = CPagerHelper::paginate($page_num, $data['items'], $sortOrder,
+		(new CUrl('disc_prototypes.php'))->setArgument('parent_discoveryid', $data['parent_discoveryid'])
+	);
 
-	$data['paging'] = getPagingLine($data['items'], $sortOrder, $url);
 	$data['parent_templates'] = getItemParentTemplates($data['items'], ZBX_FLAG_DISCOVERY_PROTOTYPE);
 
 	// render view
-	$itemView = new CView('configuration.item.prototype.list', $data);
-	$itemView->render();
-	$itemView->show();
+	echo (new CView('configuration.item.prototype.list', $data))->getOutput();
 }
 
 require_once dirname(__FILE__).'/include/page_footer.php';
