@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -44,6 +44,7 @@ $fields = [
 	'update' =>			[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
 	'clone' =>			[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
 	'delete' =>			[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
+	'cancel' =>			[T_ZBX_STR, O_OPT, P_SYS,		null,	null],
 	// other
 	'form' =>			[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
 	'form_refresh' =>	[T_ZBX_INT, O_OPT, null,	null,		null],
@@ -250,9 +251,7 @@ if (hasRequest('form')) {
 	}
 
 	// render view
-	$view = new CView('configuration.hostgroups.edit', $data);
-	$view->render();
-	$view->show();
+	echo (new CView('configuration.hostgroups.edit', $data))->getOutput();
 }
 /*
  * Display list
@@ -298,7 +297,21 @@ else {
 	]);
 	order_result($groups, $sortField, $sortOrder);
 
-	$data['paging'] = getPagingLine($groups, $sortOrder, new CUrl('hostgroups.php'));
+	// pager
+	if (hasRequest('page')) {
+		$page_num = getRequest('page');
+	}
+	elseif (isRequestMethod('get') && !hasRequest('cancel')) {
+		$page_num = 1;
+	}
+	else {
+		$page_num = CPagerHelper::loadPage($page['file']);
+	}
+
+	CPagerHelper::savePage($page['file'], $page_num);
+
+	$data['paging'] = CPagerHelper::paginate($page_num, $groups, $sortOrder, new CUrl('hostgroups.php'));
+
 	$groupIds = zbx_objectValues($groups, 'groupid');
 
 	// get hosts and templates count
@@ -329,9 +342,7 @@ else {
 	unset($group);
 
 	// render view
-	$view = new CView('configuration.hostgroups.list', $data);
-	$view->render();
-	$view->show();
+	echo (new CView('configuration.hostgroups.list', $data))->getOutput();
 }
 
 require_once dirname(__FILE__).'/include/page_footer.php';
