@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,26 +20,23 @@
 
 
 require_once dirname(__FILE__).'/include/config.inc.php';
-require_once dirname(__FILE__).'/include/hostgroups.inc.php';
 require_once dirname(__FILE__).'/include/hosts.inc.php';
 require_once dirname(__FILE__).'/include/forms.inc.php';
 
 $page['title'] = _('Host inventory');
 $page['file'] = 'hostinventories.php';
-$page['scripts'] = ['layout.mode.js'];
+$page['scripts'] = ['layout.mode.js', 'multiselect.js'];
 
 $hostId = getRequest('hostid', 0);
 
 if ($hostId > 0) {
-	CView::$has_web_layout_mode = true;
-	$page['web_layout_mode'] = CView::getLayoutMode();
+	$page['web_layout_mode'] = CViewHelper::loadLayoutMode();
 }
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
 //		VAR			TYPE	OPTIONAL FLAGS	VALIDATION	EXCEPTION
 $fields = [
-	'groupid' =>			[T_ZBX_INT, O_OPT, P_SYS,	DB_ID,		null],
 	'hostid' =>				[T_ZBX_INT, O_OPT, P_SYS,	DB_ID,		null],
 	// filter
 	'filter_set' =>			[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
@@ -47,6 +44,9 @@ $fields = [
 	'filter_field' =>		[T_ZBX_STR, O_OPT, null,	null,		null],
 	'filter_field_value' =>	[T_ZBX_STR, O_OPT, null,	null,		null],
 	'filter_exact' =>		[T_ZBX_INT, O_OPT, null,	'IN(0,1)',	null],
+	'filter_groups' =>		[T_ZBX_INT, O_OPT, null,	DB_ID,		null],
+	// actions
+	'cancel' =>				[T_ZBX_STR, O_OPT, P_SYS,		null,	null],
 	// sort and sortorder
 	'sort' =>				[T_ZBX_STR, O_OPT, P_SYS,
 								IN('"name","pr_macaddress_a","pr_name","pr_os","pr_serialno_a","pr_tag","pr_type"'),
@@ -59,9 +59,6 @@ check_fields($fields);
 /*
  * Permissions
  */
-if (getRequest('groupid') && !isReadableHostGroups([getRequest('groupid')])) {
-	access_deny();
-}
 if (getRequest('hostid') && !isReadableHosts([getRequest('hostid')])) {
 	access_deny();
 }
@@ -130,9 +127,7 @@ if ($hostId > 0) {
 	}
 
 	// view generation
-	$hostinventoriesView = new CView('inventory.host.view', $data);
-	$hostinventoriesView->render();
-	$hostinventoriesView->show();
+	echo (new CView('inventory.host.view', $data))->getOutput();
 }
 else {
 	$data = [
@@ -144,14 +139,6 @@ else {
 		'active_tab' => CProfile::get('web.hostinventories.filter.active', 1)
 	];
 
-	// filter
-	$data['pageFilter'] = new CPageFilter([
-		'groups' => [
-			'real_hosts' => true
-		],
-		'groupid' => getRequest('groupid')
-	]);
-
 	/*
 	 * Filter
 	 */
@@ -159,113 +146,135 @@ else {
 		CProfile::update('web.hostinventories.filter_field', getRequest('filter_field', ''), PROFILE_TYPE_STR);
 		CProfile::update('web.hostinventories.filter_field_value', getRequest('filter_field_value', ''), PROFILE_TYPE_STR);
 		CProfile::update('web.hostinventories.filter_exact', getRequest('filter_exact', 0), PROFILE_TYPE_INT);
-
+		CProfile::updateArray('web.hostinventories.filter_groups', getRequest('filter_groups', []), PROFILE_TYPE_ID);
 	}
 	elseif (hasRequest('filter_rst')) {
 		DBStart();
 		CProfile::delete('web.hostinventories.filter_field');
 		CProfile::delete('web.hostinventories.filter_field_value');
 		CProfile::delete('web.hostinventories.filter_exact');
+		CProfile::deleteIdx('web.hostinventories.filter_groups');
 		DBend();
 	}
 
-	$data['filterField'] = CProfile::get('web.hostinventories.filter_field', '');
-	$data['filterFieldValue'] = CProfile::get('web.hostinventories.filter_field_value', '');
-	$data['filterExact'] = CProfile::get('web.hostinventories.filter_exact', 0);
+	$data['filter'] = [
+		'field' => CProfile::get('web.hostinventories.filter_field', ''),
+		'fieldValue' => CProfile::get('web.hostinventories.filter_field_value', ''),
+		'exact' => CProfile::get('web.hostinventories.filter_exact', 0),
+		'groups' => CProfile::getArray('web.hostinventories.filter_groups', [])
+	];
 
-	if ($data['pageFilter']->groupsSelected) {
-		// which inventory fields we will need for displaying
-		$requiredInventoryFields = [
-			'name',
-			'type',
-			'os',
-			'serialno_a',
-			'tag',
-			'macaddress_a'
-		];
+	// Select filter host groups.
+	$data['filter']['groups'] = $data['filter']['groups']
+		? CArrayHelper::renameObjectsKeys(API::HostGroup()->get([
+			'output' => ['groupid', 'name'],
+			'groupids' => $data['filter']['groups'],
+			'real_hosts' => true,
+			'preservekeys' => true
+		]), ['groupid' => 'id'])
+		: [];
 
-		// checking if correct inventory field is specified for filter
-		$possibleInventoryFields = getHostInventories();
-		$possibleInventoryFields = zbx_toHash($possibleInventoryFields, 'db_field');
-		if ($data['filterField'] !== '' && $data['filterFieldValue'] !== ''
-				&& !isset($possibleInventoryFields[$data['filterField']])) {
-			error(_s('Impossible to filter by inventory field "%s", which does not exist.', $data['filterField']));
-		}
-		else {
-			// if we are filtering by field, this field is also required
-			if ($data['filterField'] !== '' && $data['filterFieldValue'] !== '') {
-				$requiredInventoryFields[] = $data['filterField'];
-			}
-
-			$options = [
-				'output' => ['hostid', 'name', 'status'],
-				'selectInventory' => $requiredInventoryFields,
-				'withInventory' => true,
-				'selectGroups' => API_OUTPUT_EXTEND,
-				'groupids' => $data['pageFilter']->groupids
-			];
-
-			if ($data['filterField'] !== '' && $data['filterFieldValue'] !== '') {
-				$options['searchInventory'] = [
-					$data['filterField'] => [$data['filterFieldValue']]
-				];
-			}
-
-			$data['hosts'] = API::Host()->get($options);
-
-			// filter exact matches
-			if ($data['filterField'] !== '' && $data['filterFieldValue'] !== '' && $data['filterExact'] != 0) {
-				$needle = mb_strtolower($data['filterFieldValue']);
-
-				foreach ($data['hosts'] as $num => $host) {
-					$haystack = mb_strtolower($data['hosts'][$num]['inventory'][$data['filterField']]);
-
-					if ($haystack !== $needle) {
-						unset($data['hosts'][$num]);
-					}
-				}
-			}
-
-			$sort_fields = [
-				'pr_name' => 'name',
-				'pr_type' => 'type',
-				'pr_os' => 'os',
-				'pr_serialno_a' => 'serialno_a',
-				'pr_tag' => 'tag',
-				'pr_macaddress_a' => 'macaddress_a'
-			];
-
-			if (array_key_exists($sortField, $sort_fields)) {
-				// copying an inventory field into the upper array level for sorting
-				foreach ($data['hosts'] as &$host) {
-					$host[$sortField] = $host['inventory'][$sort_fields[$sortField]];
-				}
-				unset($host);
-			}
-
-			$limit = $data['config']['search_limit'] + 1;
-
-			order_result($data['hosts'], $sortField, $sortOrder);
-
-			if ($sortOrder == ZBX_SORT_UP) {
-				$data['hosts'] = array_slice($data['hosts'], 0, $limit);
-			}
-			else {
-				$data['hosts'] = array_slice($data['hosts'], -$limit, $limit);
-			}
-
-			order_result($data['hosts'], $sortField, $sortOrder);
-		}
+	$filter_groupids = $data['filter']['groups'] ? array_keys($data['filter']['groups']) : null;
+	if ($filter_groupids) {
+		$filter_groupids = getSubGroups($filter_groupids);
 	}
 
-	$url = (new CUrl('hostinventories.php'))
-		->setArgument('groupid', $data['pageFilter']->groupid);
+	$data['host_inventories'] = zbx_toHash(getHostInventories(true), 'db_field');
 
-	$data['paging'] = getPagingLine($data['hosts'], $sortOrder, $url);
+	if ($data['filter']['field'] === '') {
+		$data['filter']['field'] = key($data['host_inventories']);
+	}
 
-	$hostinventoriesView = new CView('inventory.host.list', $data);
-	$hostinventoriesView->render();
-	$hostinventoriesView->show();
+	// Checking if correct inventory field is specified for filter.
+	if ($data['filter']['fieldValue'] !== ''
+			&& !array_key_exists($data['filter']['field'], $data['host_inventories'])) {
+		error(_s('Impossible to filter by inventory field "%1$s", which does not exist.', $data['filter']['field']));
+		$filter_set = false;
+	}
+	else {
+		$filter_set = true;
+	}
+
+	/*
+	 * Select data
+	 */
+	if ($filter_set) {
+		$options = [
+			'output' => ['hostid', 'name', 'status'],
+			'selectInventory' => ['name', 'type', 'os', 'serialno_a', 'tag', 'macaddress_a', $data['filter']['field']],
+			'selectGroups' => API_OUTPUT_EXTEND,
+			'groupids' => $filter_groupids,
+			'filter' => ['inventory_mode' => [HOST_INVENTORY_MANUAL, HOST_INVENTORY_AUTOMATIC]]
+		];
+
+		if ($data['filter']['fieldValue'] !== '') {
+			$options['searchInventory'] = [
+				$data['filter']['field'] => [$data['filter']['fieldValue']]
+			];
+		}
+
+		$data['hosts'] = API::Host()->get($options);
+
+		// filter exact matches
+		if ($data['filter']['fieldValue'] !== '' && $data['filter']['exact'] != 0) {
+			$needle = mb_strtolower($data['filter']['fieldValue']);
+
+			foreach ($data['hosts'] as $num => $host) {
+				$haystack = mb_strtolower($data['hosts'][$num]['inventory'][$data['filter']['field']]);
+
+				if ($haystack !== $needle) {
+					unset($data['hosts'][$num]);
+				}
+			}
+		}
+
+		$sort_fields = [
+			'pr_name' => 'name',
+			'pr_type' => 'type',
+			'pr_os' => 'os',
+			'pr_serialno_a' => 'serialno_a',
+			'pr_tag' => 'tag',
+			'pr_macaddress_a' => 'macaddress_a'
+		];
+
+		if (array_key_exists($sortField, $sort_fields)) {
+			// copying an inventory field into the upper array level for sorting
+			foreach ($data['hosts'] as &$host) {
+				$host[$sortField] = $host['inventory'][$sort_fields[$sortField]];
+			}
+			unset($host);
+		}
+
+		$limit = $data['config']['search_limit'] + 1;
+
+		order_result($data['hosts'], $sortField, $sortOrder);
+
+		if ($sortOrder == ZBX_SORT_UP) {
+			$data['hosts'] = array_slice($data['hosts'], 0, $limit);
+		}
+		else {
+			$data['hosts'] = array_slice($data['hosts'], -$limit, $limit);
+		}
+
+		order_result($data['hosts'], $sortField, $sortOrder);
+	}
+
+	// pager
+	if (hasRequest('page')) {
+		$page_num = getRequest('page');
+	}
+	elseif (isRequestMethod('get') && !hasRequest('cancel')) {
+		$page_num = 1;
+	}
+	else {
+		$page_num = CPagerHelper::loadPage($page['file']);
+	}
+
+	CPagerHelper::savePage($page['file'], $page_num);
+
+	$data['paging'] = CPagerHelper::paginate($page_num, $data['hosts'], $sortOrder, new CUrl('hostinventories.php'));
+
+	echo (new CView('inventory.host.list', $data))->getOutput();
 }
 
 require_once dirname(__FILE__).'/include/page_footer.php';
