@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -494,11 +494,13 @@ class CApplication extends CApiService {
 	}
 
 	/**
-	 * Add Items to applications.
+	 * Add items to applications.
 	 *
-	 * @param array $data
-	 * @param array $data['applications']
-	 * @param array $data['items']
+	 * @param array  $data
+	 * @param array  $data['applications']
+	 * @param string $data['applications'][]['applicationid']
+	 * @param array  $data['items']
+	 * @param string $data['items'][]['itemid']
 	 *
 	 * @return array
 	 */
@@ -619,12 +621,14 @@ class CApplication extends CApiService {
 	protected function addRelatedObjects(array $options, array $result) {
 		$result = parent::addRelatedObjects($options, $result);
 
+		$applicationids = array_keys($result);
+
 		// add application templates
 		if ($this->outputIsRequested('templateids', $options['output'])) {
 			$query = DBselect(
 				'SELECT at.application_templateid,at.applicationid,at.templateid'.
 					' FROM application_template at'.
-					' WHERE '.dbConditionInt('at.applicationid', array_keys($result))
+					' WHERE '.dbConditionInt('at.applicationid', $applicationids)
 			);
 			$relationMap = new CRelationMap();
 			$templateApplications = [];
@@ -667,7 +671,7 @@ class CApplication extends CApiService {
 			$dbRules = DBselect(
 				'SELECT ad.applicationid,ap.itemid'.
 				' FROM application_discovery ad,application_prototype ap,applications a'.
-				' WHERE '.dbConditionInt('ad.applicationid', array_keys($result)).
+				' WHERE '.dbConditionInt('ad.applicationid', $applicationids).
 					' AND ad.application_prototypeid=ap.application_prototypeid'.
 					' AND a.applicationid=ad.applicationid'.
 					' AND a.flags='.ZBX_FLAG_DISCOVERY_CREATED
@@ -693,7 +697,7 @@ class CApplication extends CApiService {
 				'output' => $this->outputExtend($options['selectApplicationDiscovery'],
 					['application_discoveryid', 'applicationid']
 				),
-				'filter' => ['applicationid' => array_keys($result)],
+				'filter' => ['applicationid' => $applicationids],
 				'preservekeys' => true
 			]);
 
