@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,7 +26,23 @@ class CItemPrototype extends CItemGeneral {
 
 	protected $tableName = 'items';
 	protected $tableAlias = 'i';
-	protected $sortColumns = ['itemid', 'name', 'key_', 'delay', 'history', 'trends', 'type', 'status'];
+	protected $sortColumns = ['itemid', 'name', 'key_', 'delay', 'history', 'trends', 'type', 'status', 'discover'];
+
+	/**
+	 * Define a set of supported pre-processing rules.
+	 *
+	 * @var array
+	 *
+	 * 5.6 would allow this to be defined constant.
+	 */
+	public static $supported_preprocessing_types = [ZBX_PREPROC_REGSUB, ZBX_PREPROC_TRIM, ZBX_PREPROC_RTRIM,
+		ZBX_PREPROC_LTRIM, ZBX_PREPROC_XPATH, ZBX_PREPROC_JSONPATH, ZBX_PREPROC_MULTIPLIER, ZBX_PREPROC_DELTA_VALUE,
+		ZBX_PREPROC_DELTA_SPEED, ZBX_PREPROC_BOOL2DEC, ZBX_PREPROC_OCT2DEC, ZBX_PREPROC_HEX2DEC,
+		ZBX_PREPROC_VALIDATE_RANGE, ZBX_PREPROC_VALIDATE_REGEX, ZBX_PREPROC_VALIDATE_NOT_REGEX,
+		ZBX_PREPROC_ERROR_FIELD_JSON, ZBX_PREPROC_ERROR_FIELD_XML, ZBX_PREPROC_ERROR_FIELD_REGEX,
+		ZBX_PREPROC_THROTTLE_VALUE, ZBX_PREPROC_THROTTLE_TIMED_VALUE, ZBX_PREPROC_SCRIPT,
+		ZBX_PREPROC_PROMETHEUS_PATTERN, ZBX_PREPROC_PROMETHEUS_TO_JSON, ZBX_PREPROC_CSV_TO_JSON, ZBX_PREPROC_STR_REPLACE
+	];
 
 	public function __construct() {
 		parent::__construct();
@@ -110,7 +126,7 @@ class CItemPrototype extends CItemGeneral {
 					')';
 		}
 
-// templateids
+		// templateids
 		if (!is_null($options['templateids'])) {
 			zbx_value2array($options['templateids']);
 
@@ -123,7 +139,7 @@ class CItemPrototype extends CItemGeneral {
 			}
 		}
 
-// hostids
+		// hostids
 		if (!is_null($options['hostids'])) {
 			zbx_value2array($options['hostids']);
 
@@ -134,14 +150,14 @@ class CItemPrototype extends CItemGeneral {
 			}
 		}
 
-// itemids
+		// itemids
 		if (!is_null($options['itemids'])) {
 			zbx_value2array($options['itemids']);
 
 			$sqlParts['where']['itemid'] = dbConditionInt('i.itemid', $options['itemids']);
 		}
 
-// discoveryids
+		// discoveryids
 		if (!is_null($options['discoveryids'])) {
 			zbx_value2array($options['discoveryids']);
 
@@ -172,7 +188,7 @@ class CItemPrototype extends CItemGeneral {
 			$sqlParts['where']['igi'] = 'i.itemid=gi.itemid';
 		}
 
-// inherited
+		// inherited
 		if (!is_null($options['inherited'])) {
 			if ($options['inherited'])
 				$sqlParts['where'][] = 'i.templateid IS NOT NULL';
@@ -180,7 +196,7 @@ class CItemPrototype extends CItemGeneral {
 				$sqlParts['where'][] = 'i.templateid IS NULL';
 		}
 
-// templated
+		// templated
 		if (!is_null($options['templated'])) {
 			$sqlParts['from']['hosts'] = 'hosts h';
 			$sqlParts['where']['hi'] = 'h.hostid=i.hostid';
@@ -191,7 +207,7 @@ class CItemPrototype extends CItemGeneral {
 				$sqlParts['where'][] = 'h.status<>'.HOST_STATUS_TEMPLATE;
 		}
 
-// monitored
+		// monitored
 		if (!is_null($options['monitored'])) {
 			$sqlParts['from']['hosts'] = 'hosts h';
 			$sqlParts['where']['hi'] = 'h.hostid=i.hostid';
@@ -205,12 +221,12 @@ class CItemPrototype extends CItemGeneral {
 			}
 		}
 
-// search
+		// search
 		if (is_array($options['search'])) {
 			zbx_db_search('items i', $options, $sqlParts);
 		}
 
-// --- FILTER ---
+		// --- FILTER ---
 		if (is_array($options['filter'])) {
 			if (array_key_exists('delay', $options['filter']) && $options['filter']['delay'] !== null) {
 				$sqlParts['where'][] = makeUpdateIntervalFilter('i.delay', $options['filter']['delay']);
@@ -236,11 +252,11 @@ class CItemPrototype extends CItemGeneral {
 			}
 		}
 
-// limit
+		// limit
 		if (zbx_ctype_digit($options['limit']) && $options['limit']) {
 			$sqlParts['limit'] = $options['limit'];
 		}
-//----------
+		//----------
 
 		$sqlParts = $this->applyQueryOutputOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
 		$sqlParts = $this->applyQuerySortOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
@@ -268,18 +284,17 @@ class CItemPrototype extends CItemGeneral {
 		}
 
 		// Decode ITEM_TYPE_HTTPAGENT encoded fields.
-		$json = new CJson();
-
 		foreach ($result as &$item) {
 			if (array_key_exists('query_fields', $item)) {
-				$query_fields = ($item['query_fields'] !== '') ? $json->decode($item['query_fields'], true) : [];
-				$item['query_fields'] = $json->hasError() ? [] : $query_fields;
+				$query_fields = ($item['query_fields'] !== '') ? json_decode($item['query_fields'], true) : [];
+				$item['query_fields'] = json_last_error() ? [] : $query_fields;
 			}
 
 			if (array_key_exists('headers', $item)) {
 				$item['headers'] = $this->headersStringToArray($item['headers']);
 			}
 		}
+		unset($item);
 
 		if (!$options['preservekeys']) {
 			$result = zbx_cleanHashes($result);
@@ -350,20 +365,34 @@ class CItemPrototype extends CItemGeneral {
 	 */
 	public function create($items) {
 		$items = zbx_toArray($items);
+
 		$this->checkInput($items);
 
 		foreach ($items as &$item) {
 			unset($item['itemid']);
 		}
+		unset($item);
 
-		$this->validateDependentItems($items, __METHOD__);
+		// Validate item prototype status and discover status fields.
+		$api_input_rules = ['type' => API_OBJECT, 'fields' => [
+			'status' => ['type' => API_INT32, 'in' => implode(',', [ITEM_STATUS_ACTIVE, ITEM_STATUS_DISABLED])],
+			'discover' => ['type' => API_INT32, 'in' => implode(',', [ITEM_DISCOVER, ITEM_NO_DISCOVER])]
+		]];
 
-		$json = new CJson();
+		foreach ($items as $key => $item) {
+			$item = array_intersect_key($item, $api_input_rules['fields']);
+
+			if (!CApiInputValidator::validate($api_input_rules, $item, '/'.($key + 1), $error)) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, $error);
+			}
+		}
+
+		$this->validateDependentItems($items);
 
 		foreach ($items as &$item) {
 			if ($item['type'] == ITEM_TYPE_HTTPAGENT) {
 				if (array_key_exists('query_fields', $item)) {
-					$item['query_fields'] = $item['query_fields'] ? $json->encode($item['query_fields']) : '';
+					$item['query_fields'] = $item['query_fields'] ? json_encode($item['query_fields']) : '';
 				}
 
 				if (array_key_exists('headers', $item)) {
@@ -480,11 +509,11 @@ class CItemPrototype extends CItemGeneral {
 		$this->createItemPreprocessing($items);
 	}
 
-	protected function updateReal($items) {
-		$items = zbx_toArray($items);
+	protected function updateReal(array $items) {
+		CArrayHelper::sort($items, ['itemid']);
 
 		$data = [];
-		foreach ($items as $inum => $item) {
+		foreach ($items as $item) {
 			$data[] = ['values' => $item, 'where'=> ['itemid' => $item['itemid']]];
 		}
 
@@ -503,7 +532,7 @@ class CItemPrototype extends CItemGeneral {
 			}
 
 			$itemidsWithApplications[] = $item['itemid'];
-			foreach ($item['applications'] as $anum => $appid) {
+			foreach ($item['applications'] as $appid) {
 				$itemApplications[] = [
 					'applicationid' => $appid,
 					'itemid' => $item['itemid']
@@ -704,7 +733,7 @@ class CItemPrototype extends CItemGeneral {
 
 		// Find and delete application prototypes from database that are no longer linked to any item prototypes.
 		if ($application_prototypes_to_remove) {
-			$this->deleteApplicationPrototypes(array_keys($application_prototypes_to_remove));
+			CItemPrototypeManager::deleteUnusedApplicationPrototypes(array_keys($application_prototypes_to_remove));
 		}
 
 		$this->updateItemPreprocessing($items);
@@ -721,7 +750,20 @@ class CItemPrototype extends CItemGeneral {
 		$items = zbx_toArray($items);
 
 		$this->checkInput($items, true);
-		$this->validateDependentItems($items, __METHOD__);
+
+		// Validate item prototype status and discover status fields.
+		$api_input_rules = ['type' => API_OBJECT, 'fields' => [
+			'status' => ['type' => API_INT32, 'in' => implode(',', [ITEM_STATUS_ACTIVE, ITEM_STATUS_DISABLED])],
+			'discover' => ['type' => API_INT32, 'in' => implode(',', [ITEM_DISCOVER, ITEM_NO_DISCOVER])]
+		]];
+
+		foreach ($items as $key => $item) {
+			$item = array_intersect_key($item, $api_input_rules['fields']);
+
+			if (!CApiInputValidator::validate($api_input_rules, $item, '/'.($key + 1), $error)) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, $error);
+			}
+		}
 
 		$db_items = $this->get([
 			'output' => ['type', 'master_itemid', 'authtype', 'allow_traps', 'retrieve_mode'],
@@ -730,7 +772,11 @@ class CItemPrototype extends CItemGeneral {
 			'preservekeys' => true
 		]);
 
-		$items = $this->extendFromObjects(zbx_toHash($items, 'itemid'), $db_items, ['type']);
+		$items = $this->extendFromObjects(zbx_toHash($items, 'itemid'), $db_items, ['type', 'authtype',
+			'master_itemid'
+		]);
+
+		$this->validateDependentItems($items);
 
 		$defaults = DB::getDefaults('items');
 		$clean = [
@@ -738,7 +784,7 @@ class CItemPrototype extends CItemGeneral {
 				'url' => '',
 				'query_fields' => '',
 				'timeout' => $defaults['timeout'],
-				'status_codes' => '',
+				'status_codes' => $defaults['status_codes'],
 				'follow_redirects' => $defaults['follow_redirects'],
 				'request_method' => $defaults['request_method'],
 				'allow_traps' => $defaults['allow_traps'],
@@ -752,23 +798,15 @@ class CItemPrototype extends CItemGeneral {
 				'verify_host' => $defaults['verify_host'],
 				'ssl_cert_file' => '',
 				'ssl_key_file' => '',
-				'authtype' => $defaults['authtype'],
-				'username' => '',
-				'password' => '',
 				'posts' => ''
 			]
 		];
 
-		$json = new CJson();
-
 		foreach ($items as &$item) {
 			$type_change = ($item['type'] != $db_items[$item['itemid']]['type']);
 
-			if ($item['type'] != ITEM_TYPE_DEPENDENT && $db_items[$item['itemid']]['master_itemid']) {
-				$item['master_itemid'] = null;
-			}
-			elseif (!array_key_exists('master_itemid', $item)) {
-				$item['master_itemid'] = $db_items[$item['itemid']]['master_itemid'];
+			if ($item['type'] != ITEM_TYPE_DEPENDENT && $db_items[$item['itemid']]['master_itemid'] != 0) {
+				$item['master_itemid'] = 0;
 			}
 
 			if ($type_change && $db_items[$item['itemid']]['type'] == ITEM_TYPE_HTTPAGENT) {
@@ -786,9 +824,8 @@ class CItemPrototype extends CItemGeneral {
 			}
 
 			if ($item['type'] == ITEM_TYPE_HTTPAGENT) {
-				// Clean username and password on authtype change to HTTPTEST_AUTH_NONE.
-				if (array_key_exists('authtype', $item) && $item['authtype'] == HTTPTEST_AUTH_NONE
-						&& $item['authtype'] != $db_items[$item['itemid']]['authtype']) {
+				// Clean username and password when authtype is set to HTTPTEST_AUTH_NONE.
+				if ($item['authtype'] == HTTPTEST_AUTH_NONE) {
 					$item['username'] = '';
 					$item['password'] = '';
 				}
@@ -799,7 +836,7 @@ class CItemPrototype extends CItemGeneral {
 				}
 
 				if (array_key_exists('query_fields', $item) && is_array($item['query_fields'])) {
-					$item['query_fields'] = $item['query_fields'] ? $json->encode($item['query_fields']) : '';
+					$item['query_fields'] = $item['query_fields'] ? json_encode($item['query_fields']) : '';
 				}
 
 				if (array_key_exists('headers', $item) && is_array($item['headers'])) {
@@ -828,207 +865,52 @@ class CItemPrototype extends CItemGeneral {
 	/**
 	 * Delete Item prototypes.
 	 *
-	 * @param array $prototypeids
-	 * @param bool 	$nopermissions
+	 * @param array $itemids
 	 *
 	 * @return array
 	 */
-	public function delete(array $prototypeids, $nopermissions = false) {
-		if (empty($prototypeids)) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
-		}
+	public function delete(array $itemids) {
+		$this->validateDelete($itemids, $db_items);
 
-		$prototypeids = array_keys(array_flip($prototypeids));
+		CItemPrototypeManager::delete($itemids);
 
-		$options = [
-			'itemids' => $prototypeids,
-			'editable' => true,
-			'preservekeys' => true,
-			'output' => API_OUTPUT_EXTEND
-		];
-		$delItemPrototypes = $this->get($options);
+		$this->addAuditBulk(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_ITEM_PROTOTYPE, $db_items);
 
-		// TODO: remove $nopermissions hack
-		if (!$nopermissions) {
-			foreach ($prototypeids as $prototypeid) {
-				if (!isset($delItemPrototypes[$prototypeid])) {
-					self::exception(ZBX_API_ERROR_PERMISSIONS, _('No permissions to referred object or it does not exist!'));
-				}
-				if ($delItemPrototypes[$prototypeid]['templateid'] != 0) {
-					self::exception(ZBX_API_ERROR_PARAMETERS, _('Cannot delete templated items'));
-				}
-			}
-		}
-
-		// first delete child items
-		$parentItemids = $prototypeids;
-		$childPrototypeids = [];
-		do {
-			$dbItems = DBselect('SELECT itemid FROM items WHERE '.dbConditionInt('templateid', $parentItemids));
-			$parentItemids = [];
-			while ($dbItem = DBfetch($dbItems)) {
-				$parentItemids[$dbItem['itemid']] = $dbItem['itemid'];
-				$childPrototypeids[$dbItem['itemid']] = $dbItem['itemid'];
-			}
-		} while ($parentItemids);
-
-		$db_dependent_items = $delItemPrototypes + $childPrototypeids;
-		$dependent_itemprototypes = [];
-		// Master item deletion will remove dependent items on database level.
-		while ($db_dependent_items) {
-			$db_dependent_items = $this->get([
-				'output' => ['itemid', 'name'],
-				'filter' => ['type' => ITEM_TYPE_DEPENDENT, 'master_itemid' => array_keys($db_dependent_items)],
-				'preservekeys' => true
-			]);
-			$db_dependent_items = array_diff_key($db_dependent_items, $dependent_itemprototypes);
-			$dependent_itemprototypes += $db_dependent_items;
-		};
-		$dependent_itemprototypeids = array_keys($dependent_itemprototypes);
-		$childPrototypeids += array_combine($dependent_itemprototypeids, $dependent_itemprototypeids);
-
-		$prototypeids = array_merge($prototypeids, $childPrototypeids);
-
-		// Delete graphs or leave them if graphs still have at least one item prototype.
-		$del_graph_prototypes = [];
-		$db_graph_prototypes = DBselect(
-			'SELECT gi.graphid'.
-			' FROM graphs_items gi'.
-			' WHERE '.dbConditionInt('gi.itemid', $prototypeids).
-				' AND NOT EXISTS ('.
-					'SELECT NULL'.
-					' FROM graphs_items gii,items i'.
-					' WHERE gi.graphid=gii.graphid'.
-						' AND gii.itemid=i.itemid'.
-						' AND '.dbConditionInt('i.itemid', $prototypeids, true).
-						' AND '.dbConditionInt('i.flags', [ZBX_FLAG_DISCOVERY_PROTOTYPE]).
-				')'
-		);
-		while ($db_graph_prototype = DBfetch($db_graph_prototypes)) {
-			$del_graph_prototypes[] = $db_graph_prototype['graphid'];
-		}
-
-		if ($del_graph_prototypes) {
-			API::GraphPrototype()->delete($del_graph_prototypes, true);
-		}
-
-		// check if any graphs are referencing this item
-		$this->checkGraphReference($prototypeids);
-
-// CREATED ITEMS
-		$createdItems = [];
-		$sql = 'SELECT itemid FROM item_discovery WHERE '.dbConditionInt('parent_itemid', $prototypeids);
-		$dbItems = DBselect($sql);
-		while ($item = DBfetch($dbItems)) {
-			$createdItems[$item['itemid']] = $item['itemid'];
-		}
-		if ($createdItems) {
-			// This API call will also make sure that discovered applications are no longer linked to other items.
-			API::Item()->delete($createdItems, true);
-		}
-
-
-// TRIGGER PROTOTYPES
-		$delTriggerPrototypes = API::TriggerPrototype()->get([
-			'output' => [],
-			'itemids' => $prototypeids,
-			'nopermissions' => true,
-			'preservekeys' => true,
-		]);
-		if ($delTriggerPrototypes) {
-			API::TriggerPrototype()->delete(array_keys($delTriggerPrototypes), true);
-		}
-
-		// screen items
-		DB::delete('screens_items', [
-			'resourceid' => $prototypeids,
-			'resourcetype' => [SCREEN_RESOURCE_LLD_SIMPLE_GRAPH]
-		]);
-
-		// Unlink application prototypes and delete those who are no longer linked to any other item prototypes.
-		$db_item_application_prototypes = DBfetchArray(DBselect(
-			'SELECT iap.item_application_prototypeid,iap.application_prototypeid'.
-			' FROM item_application_prototype iap'.
-			' WHERE '.dbConditionInt('iap.itemid', $prototypeids)
-		));
-
-		if ($db_item_application_prototypes) {
-			DB::delete('item_application_prototype', [
-				'item_application_prototypeid' => zbx_objectValues($db_item_application_prototypes,
-					'item_application_prototypeid'
-				)
-			]);
-
-			$this->deleteApplicationPrototypes(zbx_objectValues($db_item_application_prototypes,
-				'application_prototypeid'
-			));
-		}
-
-// ITEM PROTOTYPES
-		DB::delete('items', ['itemid' => $prototypeids]);
-
-		$prototypeids = array_map('strval', $prototypeids);
-
-		return ['prototypeids' => $prototypeids];
+		return ['prototypeids' => $itemids];
 	}
 
-	/*
-	 * Finds and deletes application prototypes by given IDs. Looks for discovered applications that were created from
-	 * prototypes and deletes them if they are not discovered by other rules.
+	/**
+	 * Validates the input parameters for the delete() method.
 	 *
-	 * @param array $application_prototypeids
+	 * @param array $itemids   [IN/OUT]
+	 * @param array $db_items  [OUT]
+	 *
+	 * @throws APIException if the input is invalid.
 	 */
-	protected function deleteApplicationPrototypes(array $application_prototypeids) {
-		$db_application_prototypes = DBfetchArray(DBselect(
-			'SELECT ap.application_prototypeid'.
-			' FROM application_prototype ap'.
-			' WHERE NOT EXISTS ('.
-				'SELECT NULL'.
-				' FROM item_application_prototype iap'.
-				' WHERE ap.application_prototypeid=iap.application_prototypeid'.
-			')'.
-			' AND '.dbConditionInt('ap.application_prototypeid', $application_prototypeids)
-		));
+	private function validateDelete(array &$itemids, array &$db_items = null) {
+		$api_input_rules = ['type' => API_IDS, 'flags' => API_NOT_EMPTY, 'uniq' => true];
+		if (!CApiInputValidator::validate($api_input_rules, $itemids, '/', $error)) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
+		}
 
-		if ($db_application_prototypes) {
-			// Find discovered applications for deletable application prototypes.
-			$discovered_applications = DBfetchArray(DBselect(
-				'SELECT DISTINCT ad.applicationid'.
-				' FROM application_discovery ad'.
-				' WHERE '.dbConditionInt('ad.application_prototypeid', $application_prototypeids)
-			));
+		$db_items = $this->get([
+			'output' => ['itemid', 'name', 'templateid', 'flags'],
+			'itemids' => $itemids,
+			'editable' => true,
+			'preservekeys' => true
+		]);
 
-			$db_application_prototypeids = zbx_objectValues($db_application_prototypes, 'application_prototypeid');
-
-			// unlink templated application prototype
-			DB::update('application_prototype', [
-				'values' => ['templateid' => null],
-				'where' => ['templateid' => $db_application_prototypeids]
-			]);
-
-			DB::delete('application_prototype', ['application_prototypeid' => $db_application_prototypeids]);
-
-			/*
-			 * Deleting an application prototype will automatically delete the link in 'item_application_prototype',
-			 * but it will not delete the actual discovered application. When the link is gone,
-			 * delete the discoveted application. Link between a regular item does not matter any more.
-			 */
-			if ($discovered_applications) {
-				$discovered_applicationids = zbx_objectValues($discovered_applications, 'applicationid');
-
-				$discovered_applications_to_delete = DBfetchArray(DBselect(
-					'SELECT DISTINCT ad.applicationid'.
-					' FROM application_discovery ad'.
-					' WHERE '.dbConditionInt('ad.applicationid', $discovered_applicationids)
-				));
-
-				$applications_to_delete = array_diff($discovered_applicationids,
-					zbx_objectValues($discovered_applications_to_delete, 'applicationid')
+		foreach ($itemids as $itemid) {
+			if (!array_key_exists($itemid, $db_items)) {
+				self::exception(ZBX_API_ERROR_PERMISSIONS,
+					_('No permissions to referred object or it does not exist!')
 				);
+			}
 
-				if ($applications_to_delete) {
-					API::Application()->delete($applications_to_delete, true);
-				}
+			$db_item = $db_items[$itemid];
+
+			if ($db_item['templateid'] != 0) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, _('Cannot delete templated item prototype.'));
 			}
 		}
 	}
@@ -1048,20 +930,18 @@ class CItemPrototype extends CItemGeneral {
 			'output' => $output,
 			'selectApplications' => ['applicationid'],
 			'selectApplicationPrototypes' => ['name'],
-			'selectPreprocessing' => ['type', 'params'],
+			'selectPreprocessing' => ['type', 'params', 'error_handler', 'error_handler_params'],
 			'hostids' => $data['templateids'],
 			'preservekeys' => true
 		]);
 
-		$json = new CJson();
-
 		foreach ($tpl_items as &$tpl_item) {
 			$tpl_item['applications'] = zbx_objectValues($tpl_item['applications'], 'applicationid');
 
 			if ($tpl_item['type'] == ITEM_TYPE_HTTPAGENT) {
 				if (array_key_exists('query_fields', $tpl_item) && is_array($tpl_item['query_fields'])) {
 					$tpl_item['query_fields'] = $tpl_item['query_fields']
-						? $json->encode($tpl_item['query_fields'])
+						? json_encode($tpl_item['query_fields'])
 						: '';
 				}
 
@@ -1107,70 +987,6 @@ class CItemPrototype extends CItemGeneral {
 				_s('Incorrect value for field "%1$s": %2$s.', 'trends', $error)
 			);
 		}
-
-		$this->validateItemPreprocessing($item, $method);
-	}
-
-	protected function inherit(array $items, array $hostids = null) {
-		if (!$items) {
-			return;
-		}
-
-		// prepare the child items
-		$new_items = $this->prepareInheritedItems($items, $hostids);
-		if (!$new_items) {
-			return;
-		}
-
-		$ins_items = [];
-		$upd_items = [];
-		foreach ($new_items as $new_item) {
-			if (array_key_exists('itemid', $new_item)) {
-				unset($new_item['ruleid']);
-				$upd_items[] = $new_item;
-			}
-			else {
-				// set the corresponding discovery rule id for the new items
-				$ins_items[] = $new_item;
-			}
-		}
-
-		// save the new items
-		if ($ins_items) {
-			$this->createReal($ins_items);
-		}
-
-		if ($upd_items) {
-			$this->updateReal($upd_items);
-		}
-
-		$new_items = array_merge($upd_items, $ins_items);
-
-		// Update master_itemid for inserted or updated inherited dependent items.
-		$this->inheritDependentItems($new_items);
-
-		// Inheriting items from the templates.
-		$tpl_items = DBselect(
-			'SELECT i.itemid'.
-			' FROM items i,hosts h'.
-			' WHERE i.hostid=h.hostid'.
-				' AND '.dbConditionInt('i.itemid', zbx_objectValues($new_items, 'itemid')).
-				' AND '.dbConditionInt('h.status', [HOST_STATUS_TEMPLATE])
-		);
-
-		$tpl_itemids = [];
-		while ($tpl_item = DBfetch($tpl_items)) {
-			$tpl_itemids[$tpl_item['itemid']] = true;
-		}
-
-		foreach ($new_items as $index => $new_item) {
-			if (!array_key_exists($new_item['itemid'], $tpl_itemids)) {
-				unset($new_items[$index]);
-			}
-		}
-
-		// Inheriting items from the templates.
-		$this->inherit($new_items);
 	}
 
 	protected function applyQueryOutputOptions($tableName, $tableAlias, array $options, array $sqlParts) {
@@ -1261,12 +1077,9 @@ class CItemPrototype extends CItemGeneral {
 				$triggers = zbx_toHash($triggers, 'itemid');
 
 				foreach ($result as $itemid => $item) {
-					if (isset($triggers[$itemid])) {
-						$result[$itemid]['triggers'] = $triggers[$itemid]['rowscount'];
-					}
-					else {
-						$result[$itemid]['triggers'] = 0;
-					}
+					$result[$itemid]['triggers'] = array_key_exists($itemid, $triggers)
+						? $triggers[$itemid]['rowscount']
+						: '0';
 				}
 			}
 		}
@@ -1295,12 +1108,9 @@ class CItemPrototype extends CItemGeneral {
 				$graphs = zbx_toHash($graphs, 'itemid');
 
 				foreach ($result as $itemid => $item) {
-					if (isset($graphs[$itemid])) {
-						$result[$itemid]['graphs'] = $graphs[$itemid]['rowscount'];
-					}
-					else {
-						$result[$itemid]['graphs'] = 0;
-					}
+					$result[$itemid]['graphs'] = array_key_exists($itemid, $graphs)
+						? $graphs[$itemid]['rowscount']
+						: '0';
 				}
 			}
 		}
@@ -1317,29 +1127,6 @@ class CItemPrototype extends CItemGeneral {
 			$result = $relationMap->mapOne($result, $discoveryRules, 'discoveryRule');
 		}
 
-		if ($options['selectPreprocessing'] !== null && $options['selectPreprocessing'] != API_OUTPUT_COUNT) {
-			$db_item_preproc = API::getApiService()->select('item_preproc', [
-				'output' => $this->outputExtend($options['selectPreprocessing'], ['itemid', 'step']),
-				'filter' => ['itemid' => array_keys($result)],
-			]);
-
-			CArrayHelper::sort($db_item_preproc, ['step']);
-
-			foreach ($result as &$item) {
-				$item['preprocessing'] = [];
-			}
-			unset($item);
-
-			foreach ($db_item_preproc as $step) {
-				$itemid = $step['itemid'];
-				unset($step['item_preprocid'], $step['itemid'], $step['step']);
-
-				if (array_key_exists($itemid, $result)) {
-					$result[$itemid]['preprocessing'][] = $step;
-				}
-			}
-		}
-
 		return $result;
 	}
 }
