@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -139,13 +139,12 @@ class CMenuPopupHelper {
 	 * Prepare data for Ajax trigger menu popup.
 	 *
 	 * @param string $triggerid
-	 * @param string $eventid                 (optional) Mandatory for Acknowledge menu.
-	 * @param array  $acknowledge             Acknowledge link parameters (optional).
-	 * @param string $acknowledge['backurl']
+	 * @param string $eventid      (optional) Mandatory for Acknowledge menu.
+	 * @param bool   $acknowledge  (optional) Whether to show Acknowledge menu.
 	 *
 	 * @return array
 	 */
-	public static function getTrigger($triggerid, $eventid = 0, array $acknowledge = []) {
+	public static function getTrigger($triggerid, $eventid = 0, $acknowledge = false) {
 		$data = [
 			'type' => 'trigger',
 			'data' => [
@@ -155,10 +154,7 @@ class CMenuPopupHelper {
 
 		if ($eventid != 0) {
 			$data['data']['eventid'] = $eventid;
-		}
-
-		if ($acknowledge) {
-			$data['data']['acknowledge'] = $acknowledge;
+			$data['data']['acknowledge'] = $acknowledge ? '1' : '0';
 		}
 
 		return $data;
