@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -58,6 +58,8 @@ class CValidationRule {
 
 							if (!$this->parseString($buffer, $pos, $rule)		// string
 									&& !$this->parseRangeTime($buffer, $pos, $rule)		// range time
+									&& !$this->parseTimePeriods($buffer, $pos, $rule)	// time periods
+									&& !$this->parseRgb($buffer, $pos, $rule)			// rgb
 									&& !$this->parseRequired($buffer, $pos, $rule)		// required
 									&& !$this->parseNotEmpty($buffer, $pos, $rule)		// not_empty
 									&& !$this->parseLE($buffer, $pos, $rule)			// le
@@ -171,6 +173,38 @@ class CValidationRule {
 		return true;
 	}
 
+	/**
+	 * range_time
+	 *
+	 * 'time_periods' => true
+	 */
+	private function parseTimePeriods($buffer, &$pos, &$rules) {
+		if (strncmp(substr($buffer, $pos), 'time_periods', 12) != 0) {
+			return false;
+		}
+
+		$pos += 12;
+		$rules['time_periods'] = true;
+
+		return true;
+	}
+
+	/**
+	 * rgb
+	 *
+	 * 'rgb' => true
+	 */
+	private function parseRgb($buffer, &$pos, &$rules) {
+		if (strncmp(substr($buffer, $pos), 'rgb', 3) != 0) {
+			return false;
+		}
+
+		$pos += 3;
+		$rules['rgb'] = true;
+
+		return true;
+	}
+
 	/**
 	 * required
 	 *
