@@ -247,9 +247,6 @@ class CScreenBuilder {
 			case SCREEN_RESOURCE_HISTORY:
 				return new CScreenHistory($options);
 
-			case SCREEN_RESOURCE_CHART:
-				return new CScreenChart($options);
-
 			case SCREEN_RESOURCE_LLD_GRAPH:
 				$options = self::appendTemplatedScreenOption($options);
 				return new CScreenLldGraph($options);
@@ -462,8 +459,9 @@ class CScreenBuilder {
 						&& (isset($_REQUEST['form']) && $_REQUEST['form'] == 'update')
 						&& ((isset($_REQUEST['x']) && $_REQUEST['x'] == $c && isset($_REQUEST['y']) && $_REQUEST['y'] == $r)
 								|| (isset($_REQUEST['screenitemid']) && bccomp($_REQUEST['screenitemid'], $screenitem['screenitemid']) == 0))) {
-					$screenView = new CView('monitoring.screen.constructor.edit', ['screen' => $this->screen]);
-					$item = $screenView->render();
+					$item = new CObject(
+						(new CView('monitoring.screen.constructor.edit', ['screen' => $this->screen]))->getOutput()
+					);
 					$isEditForm = true;
 				}
 				// screen cell
