@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,18 +18,18 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
+
 class CActionCondValidator extends CValidator {
 
 	/**
 	 * Returns true if the given $value is valid, or set's an error and returns false otherwise.
 	 *
-	 *
-	 * @param $condition
+	 * @param array $condition
 	 *
 	 * @return bool
 	 */
 	public function validate($condition) {
-		// build validators
+		// Build validators.
 		$discoveryCheckTypeValidator = new CLimitedSetValidator([
 			'values' => array_keys(discovery_check_type2str())
 		]);
@@ -49,63 +49,48 @@ class CActionCondValidator extends CValidator {
 		$discoveryObjectValidator = new CLimitedSetValidator([
 			'values' => array_keys(discovery_object2str())
 		]);
-		$triggerValueValidator = new CLimitedSetValidator([
-			'values' => array_keys(trigger_value2str())
-		]);
 		$eventTypeValidator = new CLimitedSetValidator([
 			'values' => array_keys(eventType())
 		]);
 
-		$conditionValue = $condition['value'];
-		// validate condition values depending on condition type
+		// Validate condition values depending on condition type.
 		switch ($condition['conditiontype']) {
 			case CONDITION_TYPE_HOST_GROUP:
-				if (!$conditionValue) {
-					$this->setError(_('Empty action condition.'));
-				}
-				break;
-
 			case CONDITION_TYPE_TEMPLATE:
-				if (!$conditionValue) {
-					$this->setError(_('Empty action condition.'));
-				}
-				break;
-
 			case CONDITION_TYPE_TRIGGER:
-				if (!$conditionValue) {
-					$this->setError(_('Empty action condition.'));
-				}
-				break;
-
 			case CONDITION_TYPE_HOST:
-				if (!$conditionValue) {
-					$this->setError(_('Empty action condition.'));
-				}
-				break;
-
 			case CONDITION_TYPE_DRULE:
-				if (!$conditionValue) {
-					$this->setError(_('Empty action condition.'));
+			case CONDITION_TYPE_PROXY:
+				if (zbx_empty($condition['value']) || $condition['value'] === '0') {
+					$this->setError(_s('Incorrect value for field "%1$s": %2$s.', 'value', _('cannot be empty')));
+				}
+				elseif (is_array($condition['value'])) {
+					foreach ($condition['value'] as $value) {
+						if (zbx_empty($value) || $value == 0) {
+							$this->setError(
+								_s('Incorrect value for field "%1$s": %2$s.', 'value', _('cannot be empty'))
+							);
+							break;
+						}
+					}
 				}
 				break;
 
 			case CONDITION_TYPE_DCHECK:
-				if (!$conditionValue) {
-					$this->setError(_('Empty action condition.'));
-				}
-				break;
-
-			case CONDITION_TYPE_PROXY:
-				if (!$conditionValue) {
-					$this->setError(_('Empty action condition.'));
+				if (!$condition['value']) {
+					$this->setError(
+						_s('Incorrect value for field "%1$s": %2$s.', 'value', _('cannot be empty'))
+					);
 				}
 				break;
 
 			case CONDITION_TYPE_DOBJECT:
-				if (zbx_empty($conditionValue)) {
-					$this->setError(_('Empty action condition.'));
+				if (zbx_empty($condition['value'])) {
+					$this->setError(
+						_s('Incorrect value for field "%1$s": %2$s.', 'value', _('cannot be empty'))
+					);
 				}
-				elseif (!$discoveryObjectValidator->validate($conditionValue)) {
+				elseif (!$discoveryObjectValidator->validate($condition['value'])) {
 					$this->setError(_('Incorrect action condition discovery object.'));
 				}
 				break;
@@ -113,68 +98,68 @@ class CActionCondValidator extends CValidator {
 			case CONDITION_TYPE_TIME_PERIOD:
 				$time_period_parser = new CTimePeriodsParser(['usermacros' => true]);
 
-				if ($time_period_parser->parse($conditionValue) != CParser::PARSE_SUCCESS) {
+				if ($time_period_parser->parse($condition['value']) != CParser::PARSE_SUCCESS) {
 					$this->setError(_('Invalid time period.'));
 				}
 				break;
 
 			case CONDITION_TYPE_DHOST_IP:
 				$ip_range_parser = new CIPRangeParser(['v6' => ZBX_HAVE_IPV6, 'dns' => false, 'max_ipv4_cidr' => 30]);
-				if (zbx_empty($conditionValue)) {
-					$this->setError(_('Empty action condition.'));
+				if (zbx_empty($condition['value'])) {
+					$this->setError(_s('Incorrect value for field "%1$s": %2$s.', 'value', _('cannot be empty')));
 				}
-				elseif (!$ip_range_parser->parse($conditionValue)) {
+				elseif (!$ip_range_parser->parse($condition['value'])) {
 					$this->setError(_s('Invalid action condition: %1$s.', $ip_range_parser->getError()));
 				}
 				break;
 
 			case CONDITION_TYPE_DSERVICE_TYPE:
-				if (zbx_empty($conditionValue)) {
-					$this->setError(_('Empty action condition.'));
+				if (zbx_empty($condition['value'])) {
+					$this->setError(_s('Incorrect value for field "%1$s": %2$s.', 'value', _('cannot be empty')));
 				}
-				elseif (!$discoveryCheckTypeValidator->validate($conditionValue)) {
+				elseif (!$discoveryCheckTypeValidator->validate($condition['value'])) {
 					$this->setError(_('Incorrect action condition discovery check.'));
 				}
 				break;
 
 			case CONDITION_TYPE_DSERVICE_PORT:
-				if (zbx_empty($conditionValue)) {
-					$this->setError(_('Empty action condition.'));
+				if (zbx_empty($condition['value'])) {
+					$this->setError(_s('Incorrect value for field "%1$s": %2$s.', 'value', _('cannot be empty')));
 				}
-				elseif (!validate_port_list($conditionValue)) {
-					$this->setError(_s('Incorrect action condition port "%1$s".', $conditionValue));
+				elseif (!validate_port_list($condition['value'])) {
+					$this->setError(_s('Incorrect action condition port "%1$s".', $condition['value']));
 				}
 				break;
 
 			case CONDITION_TYPE_DSTATUS:
-				if (zbx_empty($conditionValue)) {
-					$this->setError(_('Empty action condition.'));
+				if (zbx_empty($condition['value'])) {
+					$this->setError(_s('Incorrect value for field "%1$s": %2$s.', 'value', _('cannot be empty')));
 				}
-				elseif (!$discoveryObjectStatusValidator->validate($conditionValue)) {
+				elseif (!$discoveryObjectStatusValidator->validate($condition['value'])) {
 					$this->setError(_('Incorrect action condition discovery status.'));
 				}
 				break;
 
 			case CONDITION_TYPE_SUPPRESSED:
-				if (!zbx_empty($conditionValue)) {
-					$this->setError(_('Action condition value must be empty.'));
+				if (!zbx_empty($condition['value'])) {
+					$this->setError(_s('Incorrect value for field "%1$s": %2$s.', 'value', _('should be empty')));
 				}
 				break;
 
 			case CONDITION_TYPE_TRIGGER_SEVERITY:
-				if (zbx_empty($conditionValue)) {
-					$this->setError(_('Empty action condition.'));
+				if (zbx_empty($condition['value'])) {
+					$this->setError(_s('Incorrect value for field "%1$s": %2$s.', 'value', _('cannot be empty')));
 				}
-				elseif (!$triggerSeverityValidator->validate($conditionValue)) {
+				elseif (!$triggerSeverityValidator->validate($condition['value'])) {
 					$this->setError(_('Incorrect action condition trigger severity.'));
 				}
 				break;
 
 			case CONDITION_TYPE_EVENT_TYPE:
-				if (zbx_empty($conditionValue)) {
-					$this->setError(_('Empty action condition.'));
+				if (zbx_empty($condition['value'])) {
+					$this->setError(_s('Incorrect value for field "%1$s": %2$s.', 'value', _('cannot be empty')));
 				}
-				elseif (!$eventTypeValidator->validate($conditionValue)) {
+				elseif (!$eventTypeValidator->validate($condition['value'])) {
 					$this->setError(_('Incorrect action condition event type.'));
 				}
 				break;
@@ -186,15 +171,24 @@ class CActionCondValidator extends CValidator {
 			case CONDITION_TYPE_HOST_NAME:
 			case CONDITION_TYPE_HOST_METADATA:
 			case CONDITION_TYPE_EVENT_TAG:
-				if (zbx_empty($conditionValue)) {
-					$this->setError(_('Empty action condition.'));
+				if (zbx_empty($condition['value'])) {
+					$this->setError(_s('Incorrect value for field "%1$s": %2$s.', 'value', _('cannot be empty')));
 				}
 				break;
 
 			case CONDITION_TYPE_EVENT_TAG_VALUE:
-				if (!is_string($condition['value']) || $condition['value'] === '' ||
-						!is_string($condition['value2']) || $condition['value2'] === '') {
-					$this->setError(_('Empty action condition.'));
+				if (!is_string($condition['value2']) || $condition['value2'] === '') {
+					$this->setError(_s('Incorrect value for field "%1$s": %2$s.', 'value2', _('cannot be empty')));
+				}
+				elseif (!is_string($condition['value'])) {
+					$this->setError(
+						_s('Incorrect value for field "%1$s": %2$s.', 'value', _('a character string is expected'))
+					);
+				}
+				elseif (array_key_exists('operator', $condition) && $condition['value'] === ''
+						&& ($condition['operator'] == CONDITION_OPERATOR_LIKE
+							|| $condition['operator'] == CONDITION_OPERATOR_NOT_LIKE)) {
+					$this->setError(_s('Incorrect value for field "%1$s": %2$s.', 'value', _('cannot be empty')));
 				}
 				break;
 
