@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,25 +18,40 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
+
+/**
+ * @var CView $this
+ */
+
 $auditWidget = (new CWidget())->setTitle(_('Action log'));
 
 // create filter
-$filterForm = new CFilter('web.auditacts.filter.state');
-
 $filterColumn = new CFormList();
-$filterColumn->addRow(_('Recipient'), [
-	(new CTextBox('alias', $this->data['alias']))
-		->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH)
-		->setAttribute('autofocus', 'autofocus'),
-	(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-	(new CButton('btn1', _('Select')))
-		->addClass(ZBX_STYLE_BTN_GREY)
-		->onClick('return PopUp("popup.php?dstfrm=zbx_filter&dstfld1=alias&srctbl=users&srcfld1=alias");')
+$filterColumn->addRow(new CLabel(_('Recipients'), 'filter_userids__ms'), [
+	(new CMultiSelect([
+		'name' => 'filter_userids[]',
+		'object_name' => 'users',
+		'data' => $data['filter_userids'],
+		'placeholder' => '',
+		'popup' => [
+			'parameters' => [
+				'srctbl' => 'users',
+				'srcfld1' => 'userid',
+				'srcfld2' => 'fullname',
+				'dstfrm' => 'zbx_filter',
+				'dstfld1' => 'filter_userids_'
+			]
+		]
+	]))->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH)
 ]);
 
-$filterForm->addColumn($filterColumn);
-$filterForm->addNavigator();
-$auditWidget->addItem($filterForm);
+$auditWidget->addItem(
+	(new CFilter(new CUrl('auditacts.php')))
+		->setProfile($data['timeline']['profileIdx'])
+		->setActiveTab($data['active_tab'])
+		->addTimeSelector($data['timeline']['from'], $data['timeline']['to'])
+		->addFilterTab(_('Filter'), [$filterColumn])
+);
 
 // create form
 $auditForm = (new CForm('get'))->setName('auditForm');
@@ -95,13 +110,13 @@ foreach ($this->data['alerts'] as $alert) {
 	}
 
 	$recipient = (isset($alert['userid']) && $alert['userid'])
-		? [bold(getUserFullname($this->data['users'][$alert['userid']])), BR(), $alert['sendto']]
-		: $alert['sendto'];
+		? makeEventDetailsTableUser($alert + ['action_type' => ZBX_EVENT_HISTORY_ALERT], $data['users'])
+		: zbx_nl2br($alert['sendto']);
 
 	$auditTable->addRow([
 		zbx_date2str(DATE_TIME_FORMAT_SECONDS, $alert['clock']),
 		$this->data['actions'][$alert['actionid']]['name'],
-		($mediatype) ? $mediatype['description'] : '',
+		($mediatype) ? $mediatype['name'] : '',
 		$recipient,
 		$message,
 		$status,
@@ -118,15 +133,8 @@ $objData = [
 	'domid' => 'events',
 	'loadSBox' => 0,
 	'loadImage' => 0,
-	'loadScroll' => 1,
 	'dynamic' => 0,
-	'mainObject' => 1,
-	'periodFixed' => CProfile::get('web.auditacts.timelinefixed', 1),
-	'sliderMaximumTimePeriod' => ZBX_MAX_PERIOD,
-	'profile' => [
-		'idx' => 'web.auditacts',
-		'idx2' => 0
-	]
+	'mainObject' => 1
 ];
 zbx_add_post_js('timeControl.addObject("events", '.zbx_jsvalue($data['timeline']).', '.zbx_jsvalue($objData).');');
 zbx_add_post_js('timeControl.processObjects();');
@@ -134,4 +142,4 @@ zbx_add_post_js('timeControl.processObjects();');
 // append form to widget
 $auditWidget->addItem($auditForm);
 
-return $auditWidget;
+$auditWidget->show();
