@@ -19,6 +19,10 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 require_once dirname(__FILE__).'/js/configuration.item.list.js.php';
 
 $widget = (new CWidget())
@@ -176,7 +180,7 @@ foreach ($data['items'] as $item) {
 		$triggerHintTable->addRow([
 			getSeverityCell($trigger['priority'], $data['config']),
 			$trigger_description,
-			$expression,
+			(new CDiv($expression))->addClass(ZBX_STYLE_WORDWRAP),
 			(new CSpan(triggerIndicator($trigger['status'], $trigger['state'])))
 				->addClass(triggerIndicatorStyle($trigger['status'], $trigger['state']))
 		]);
@@ -222,7 +226,7 @@ foreach ($data['items'] as $item) {
 		($data['hostid'] == 0) ? $item['host'] : null,
 		$description,
 		$triggerInfo,
-		CHtml::encode($item['key_']),
+		(new CDiv(CHtml::encode($item['key_'])))->addClass(ZBX_STYLE_WORDWRAP),
 		$item['delay'],
 		$item['history'],
 		$item['trends'],
@@ -233,6 +237,15 @@ foreach ($data['items'] as $item) {
 	]);
 }
 
+$massclearhistory = [
+	'name' => _('Clear history'),
+	'confirm' => _('Delete history of selected items?')
+];
+
+if ($data['config']['compression_status']) {
+	unset($massclearhistory['confirm']);
+}
+
 // append table to form
 $itemForm->addItem([
 	$itemTable,
@@ -241,10 +254,8 @@ $itemForm->addItem([
 		[
 			'item.massenable' => ['name' => _('Enable'), 'confirm' => _('Enable selected items?')],
 			'item.massdisable' => ['name' => _('Disable'), 'confirm' => _('Disable selected items?')],
-			'item.masscheck_now' => ['name' => _('Check now')],
-			'item.massclearhistory' => ['name' => _('Clear history'),
-				'confirm' => _('Delete history of selected items?')
-			],
+			'item.masscheck_now' => ['name' => _('Execute now')],
+			'item.massclearhistory' => $massclearhistory,
 			'item.masscopyto' => ['name' => _('Copy')],
 			'item.massupdateform' => ['name' => _('Mass update')],
 			'item.massdelete' => ['name' => _('Delete'), 'confirm' => _('Delete selected items?')]
@@ -256,4 +267,4 @@ $itemForm->addItem([
 // append form to widget
 $widget->addItem($itemForm);
 
-return $widget;
+$widget->show();
