@@ -1,3 +1,29 @@
+<?php
+/*
+** Zabbix
+** Copyright (C) 2001-2020 Zabbix SIA
+**
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program; if not, write to the Free Software
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+**/
+
+
+/**
+ * @var CView $this
+ */
+?>
+
 <script type="text/javascript">
 	jQuery(function($) {
 		var	editableTable = function(elm, tmpl) {
@@ -12,7 +38,7 @@
 					items: 'tbody tr.sortable',
 					axis: 'y',
 					containment: 'parent',
-					cursor: IE ? 'move' : 'grabbing',
+					cursor: 'grabbing',
 					handle: 'div.<?= ZBX_STYLE_DRAG_ICON ?>',
 					tolerance: 'pointer',
 					opacity: 0.6,
