@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,6 +19,10 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 $filterForm = new CFilter(new CUrl('toptriggers.php'));
 
 $severities = [];
@@ -30,7 +34,7 @@ foreach (range(TRIGGER_SEVERITY_NOT_CLASSIFIED, TRIGGER_SEVERITY_COUNT - 1) as $
 }
 
 $filter_column = (new CFormList())
-	->addRow((new CLabel(_('Host groups'), 'groupids__ms')),
+	->addRow(new CLabel(_('Host groups'), 'groupids__ms'),
 		(new CMultiSelect([
 			'name' => 'groupids[]',
 			'object_name' => 'hostGroup',
@@ -47,12 +51,15 @@ $filter_column = (new CFormList())
 			]
 		]))->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH)
 	)
-	->addRow((new CLabel(_('Hosts'), 'hostids__ms')),
+	->addRow(new CLabel(_('Hosts'), 'hostids__ms'),
 		(new CMultiSelect([
 			'name' => 'hostids[]',
 			'object_name' => 'hosts',
 			'data' => $data['multiSelectHostData'],
 			'popup' => [
+				'filter_preselect_fields' => [
+					'hostgroups' => 'groupids_'
+				],
 				'parameters' => [
 					'srctbl' => 'hosts',
 					'srcfld1' => 'hostid',
@@ -62,12 +69,8 @@ $filter_column = (new CFormList())
 			]
 		]))->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH)
 	)
-	->addRow(_('Severity'),
-		(new CCheckBoxList('severities'))
-			->setOptions($severities)
-			->setChecked($data['filter']['severities'])
-			->addClass(ZBX_STYLE_COLUMNS)
-			->addClass(ZBX_STYLE_COLUMNS_3)
+	->addRow(new CLabel(_('Severity')),
+		(new CSeverityCheckBoxList('severities'))->setChecked($data['filter']['severities'])
 	);
 
 $filterForm
@@ -88,7 +91,7 @@ foreach ($data['triggers'] as $trigger) {
 	}
 
 	$triggerDescription = (new CLinkAction($trigger['description']))
-		->setMenuPopup(CMenuPopupHelper::getTrigger($trigger['triggerid'], 0, [], false));
+		->setMenuPopup(CMenuPopupHelper::getTrigger($trigger['triggerid'], 0));
 
 	$table->addRow([
 		$hostName,
@@ -109,7 +112,8 @@ $obj_data = [
 zbx_add_post_js('timeControl.addObject("toptriggers", '.zbx_jsvalue($data['filter']).', '.zbx_jsvalue($obj_data).');');
 zbx_add_post_js('timeControl.processObjects();');
 
-return (new CWidget())
+(new CWidget())
 	->setTitle(_('100 busiest triggers'))
 	->addItem($filterForm)
-	->addItem($table);
+	->addItem($table)
+	->show();
