@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -41,12 +41,18 @@ $fields = [
 ];
 check_fields($fields);
 
+$config = select_config();
+
 if (hasRequest('reconnect') && CWebUser::isLoggedIn()) {
+	if ($config['saml_auth_enabled'] == ZBX_AUTH_SAML_ENABLED && $config['saml_slo_url'] !== ''
+			&& CSession::keyExists('saml_data')) {
+		redirect('index_sso.php?slo');
+	}
+
 	CWebUser::logout();
 	redirect('index.php');
 }
 
-$config = select_config();
 $autologin = hasRequest('enter') ? getRequest('autologin', 0) : getRequest('autologin', 1);
 $request = getRequest('request', '');
 
@@ -87,13 +93,14 @@ if (CWebUser::isLoggedIn() && !CWebUser::isGuest()) {
 
 $messages = clear_messages();
 
-(new CView('general.login', [
-	'http_login_url' => $config['http_auth_enabled'] == ZBX_AUTH_HTTP_ENABLED
+echo (new CView('general.login', [
+	'http_login_url' => ($config['http_auth_enabled'] == ZBX_AUTH_HTTP_ENABLED)
 		? (new CUrl('index_http.php'))->setArgument('request', getRequest('request'))
 		: '',
+	'saml_login_url' => ($config['saml_auth_enabled'] == ZBX_AUTH_SAML_ENABLED)
+		? (new CUrl('index_sso.php'))->setArgument('request', getRequest('request'))
+		: '',
 	'guest_login_url' => CWebUser::isGuestAllowed() ? (new CUrl())->setArgument('enter', ZBX_GUEST_USER) : '',
 	'autologin' => $autologin == 1,
-	'error' => hasRequest('enter') && $messages ? array_pop($messages) : null
-]))
-	->disableJsLoader()
-	->render();
+	'error' => (hasRequest('enter') && $messages) ? array_pop($messages) : null
+]))->getOutput();
