@@ -21,6 +21,7 @@
 /**
  * An object that is used to namespace objects, allows to retrieve and write objects via arbitrary path.
  */
+
 window.ZABBIX = Object.create({
 
 	/**
@@ -68,21 +69,25 @@ jQuery(function($) {
 	if ($search.length) {
 		createSuggest('search');
 
-		$search.keyup(function() {
-			$search
-				.siblings('button')
-				.prop('disabled', ($.trim($search.val()) === ''));
-		}).closest('form').submit(function() {
-			if ($.trim($search.val()) === '') {
+		var $search_icon = $search.siblings('.search-icon');
+
+		$search.on('keyup', function() {
+			$search_icon.prop('disabled', $.trim($search.val()) === '');
+		});
+
+		$search.closest('form').on('submit', function() {
+			return ($.trim($search.val()) !== '');
+		});
+
+		$search_icon.on('click', function() {
+			if ($('.sidebar').is('.is-compact:not(.is-opened)')) {
+				$search.focus();
+
 				return false;
 			}
 		});
 	}
 
-	if (IE) {
-		setTimeout(function () { $('[autofocus]').focus(); }, 10);
-	}
-
 	/**
 	 * Change combobox color according selected option.
 	 */
@@ -126,58 +131,75 @@ jQuery(function($) {
 		});
 	});
 
-	function showMenuPopup($obj, data, event) {
+	function showMenuPopup($obj, data, event, options) {
+		var sections;
+
 		switch (data.type) {
 			case 'history':
-				data = getMenuPopupHistory(data);
+				sections = getMenuPopupHistory(data);
 				break;
 
 			case 'host':
-				data = getMenuPopupHost(data, $obj);
+				sections = getMenuPopupHost(data, $obj);
 				break;
 
 			case 'map_element_submap':
-				data = getMenuPopupMapElementSubmap(data);
+				sections = getMenuPopupMapElementSubmap(data);
 				break;
 
 			case 'map_element_group':
-				data = getMenuPopupMapElementGroup(data);
+				sections = getMenuPopupMapElementGroup(data);
 				break;
 
 			case 'map_element_trigger':
-				data = getMenuPopupMapElementTrigger(data);
+				sections = getMenuPopupMapElementTrigger(data);
 				break;
 
 			case 'map_element_image':
-				data = getMenuPopupMapElementImage(data);
+				sections = getMenuPopupMapElementImage(data);
 				break;
 
 			case 'refresh':
-				data = getMenuPopupRefresh(data, $obj);
+				sections = getMenuPopupRefresh(data, $obj);
 				break;
 
 			case 'trigger':
-				data = getMenuPopupTrigger(data, $obj);
+				sections = getMenuPopupTrigger(data, $obj);
 				break;
 
 			case 'trigger_macro':
-				data = getMenuPopupTriggerMacro(data);
+				sections = getMenuPopupTriggerMacro(data);
 				break;
 
 			case 'dashboard':
-				data = getMenuPopupDashboard(data, $obj);
+				sections = getMenuPopupDashboard(data, $obj);
 				break;
 
 			case 'item':
-				data = getMenuPopupItem(data, $obj);
+				sections = getMenuPopupItem(data, $obj);
 				break;
 
 			case 'item_prototype':
-				data = getMenuPopupItemPrototype(data);
+				sections = getMenuPopupItemPrototype(data);
 				break;
+
+			case 'dropdown':
+				sections = getMenuPopupDropdown(data, $obj);
+				break;
+
+			case 'submenu':
+				sections = getMenuPopupSubmenu(data);
+				break;
+
+			case 'widget_actions':
+				sections = getMenuPopupWidgetActions(data, $obj);
+				break;
+
+			default:
+				return;
 		}
 
-		$obj.menuPopup(data, event);
+		$obj.menuPopup(sections, event, options);
 	}
 
 	/**
@@ -186,9 +208,8 @@ jQuery(function($) {
 	function createMenuPopupPreloader() {
 		return $('<div>', {
 			'id': 'menu-popup-preloader',
-			'class': 'preloader-container menu-popup-preloader'
+			'class': 'is-loading menu-popup-preloader'
 		})
-			.append($('<div>').addClass('preloader'))
 			.appendTo($('body'))
 			.on('click', function(e) {
 				e.stopPropagation();
@@ -203,66 +224,117 @@ jQuery(function($) {
 		overlayPreloaderDestroy(event.data.id);
 	}
 
+	/**
+	 * Is request to a server required to process and update the data passed to the popup menu?
+	 *
+	 * @param string type  A menu popup type.
+	 *
+	 * @returns boolean
+	 */
+	function isServerRequestRequired(type) {
+		switch (type) {
+			case 'dropdown':
+			case 'submenu':
+				return false;
+
+			default:
+				return true;
+		}
+	}
+
+	/**
+	 * Make a default position object for the menu popup, based on it's type.
+	 *
+	 * @param object $obj   Menu popup opener object.
+	 * @param object data   Menu popup data object.
+	 * @param object event  Original opener event.
+	 */
+	function makeDefaultPosition($obj, data, event) {
+		switch (data.type) {
+			case 'dropdown':
+				return {
+					of: $obj,
+					my: 'left top',
+					at: 'left top+24',
+					collision: 'none'
+				};
+
+			case 'submenu':
+				return {
+					of: $obj,
+					my: 'left top',
+					at: 'left bottom+10'
+				};
+
+			default:
+				// Should match the default algorithm used in $.menuPopup().
+				return {
+					of: (event.type === 'click' && event.originalEvent.detail) ? event : event.target,
+					my: 'left top',
+					at: 'left bottom'
+				};
+		}
+	}
+
 	/**
 	 * Build menu popup for given elements.
 	 */
 	$(document).on('keydown click', '[data-menu-popup]', function(event) {
 		var $obj = $(this),
-			data = $obj.data('menu-popup'),
-			position_target = event.target;
+			data = $obj.data('menu-popup');
 
 		if (event.type === 'keydown' && event.which != 13) {
 			return;
 		}
-		else if (event.type === 'contextmenu' || (IE && $obj.closest('svg').length > 0)
-			|| event.originalEvent.detail !== 0) {
-			position_target = event;
-		}
 
 		// Manually trigger event for menuPopupPreloaderCloseHandler call for the previous preloader.
 		if ($('#menu-popup-preloader').length) {
 			$(document).trigger('click');
 		}
 
-		var	$preloader = createMenuPopupPreloader(),
-			url = new Curl('zabbix.php');
+		// Close other action menus and prevent focus jumping before opening a new popup.
+		$('.menu-popup-top').menuPopup('close', null, false);
 
-		url.setArgument('action', 'menu.popup');
-		url.setArgument('type', data.type);
+		// Create options object based on original options.
+		var options = $.extend({
+			position: makeDefaultPosition($obj, data, event)
+		}, data.options || {});
 
-		var xhr = $.ajax({
-			url: url.getUrl(),
-			method: 'POST',
-			data: {
-				data: data.data
-			},
-			dataType: 'json',
-			beforeSend: function() {
-				// Close other action menus and prevent focus jumping before opening a new popup.
-				$('.menu-popup-top').menuPopup('close', null, false);
-				setTimeout(function(){
-					$preloader
-						.fadeIn(200)
-						.position({
-							of: position_target,
-							my: 'left top',
-							at: 'left bottom'
-						});
-				}, 500);
-			},
-			success: function(resp) {
+		if (isServerRequestRequired(data.type)) {
+			var url = new Curl('zabbix.php');
+
+			url.setArgument('action', 'menu.popup');
+			url.setArgument('type', data.type);
+
+			var xhr = $.ajax({
+					url: url.getUrl(),
+					method: 'POST',
+					data: {
+						data: data.data
+					},
+					dataType: 'json'
+				});
+
+			var	$preloader = createMenuPopupPreloader();
+
+			setTimeout(function() {
+				$preloader.fadeIn(200).position(options.position);
+			}, 500);
+
+			addToOverlaysStack($preloader.prop('id'), event.target, 'preloader', xhr);
+
+			xhr.done(function(resp) {
 				overlayPreloaderDestroy($preloader.prop('id'));
-				showMenuPopup($obj, resp.data, event);
-			},
-			error: function() {
-			}
-		});
+				showMenuPopup($obj, resp.data, event, options);
+			});
 
-		addToOverlaysStack($preloader.prop('id'), event.target, 'preloader', xhr);
-
-		$(document)
-			.off('click', menuPopupPreloaderCloseHandler)
-			.on('click', {id: $preloader.prop('id')}, menuPopupPreloaderCloseHandler);
+			$(document)
+				.off('click', menuPopupPreloaderCloseHandler)
+				.on('click', {id: $preloader.prop('id')}, menuPopupPreloaderCloseHandler);
+		}
+		else {
+			showMenuPopup($obj, jQuery.extend({type: data.type}, data.data), event, options);
+		}
 
 		return false;
 	});
@@ -320,4 +392,57 @@ jQuery(function($) {
 
 	// Initialize hintBox event handlers.
 	hintBox.bindEvents();
+
+	// Simulate Safari behaviour when text in a text field with autofocus becomes selected after page has loaded.
+	if (!SF) {
+		$('input[type=text][autofocus=autofocus]').filter(':visible').select();
+	}
+
+	/**
+	 * @param {boolean} preserve_state  Preserve current state of the debug button.
+	 *
+	 * @returns {boolean} false
+	 */
+	function debug_click_handler(preserve_state) {
+		var $button = $(this),
+			visible = sessionStorage.getItem('debug-info-visible') === '1';
+
+		if (preserve_state !== true) {
+			visible = !visible;
+
+			sessionStorage.setItem('debug-info-visible', visible ? '1' : '0');
+		}
+
+		$button.text(visible ? t('Hide debug') : t('Debug'));
+
+		var style = $button.data('debug-info-style');
+		if (style) {
+			style.sheet.deleteRule(0);
+		}
+		else {
+			style = document.createElement('style');
+			$button.data('debug-info-style', style);
+			document.head.appendChild(style);
+		}
+
+		// ZBX_STYLE_DEBUG_OUTPUT
+		style.sheet.insertRule('.debug-output { display: ' + (visible ? 'block' : 'none') + '; }', 0);
+
+		if (preserve_state !== true) {
+			$.publish('debug.click', {
+				visible: visible
+			});
+		}
+
+		return false;
+	}
+
+	// Initialize ZBX_STYLE_BTN_DEBUG debug button and debug info state.
+	$('.btn-debug').each(function(index, button) {
+		$(button)
+			.on('click', debug_click_handler)
+			.addClass('visible');
+
+		debug_click_handler.call(button, true);
+	});
 });
